

/*
Author        : ZULQANI FAUZI
Created Date  : 05 / 07 / 2018
Updated Date  : 16 / 07 / 2018
*/

import {Component} from '@angular/core';
import {IonicPage, NavController, NavParams, AlertController, ToastController, ModalController} from 'ionic-angular';
import {AuthService} from "../../providers/auth-service";
import {Common} from "../../providers/common";
import {CalendarModal, CalendarModalOptions, CalendarResult} from "ion2-calendar";
import {ManagementKasFormPage} from '../management-kas-form/management-kas-form';

@IonicPage()
@Component({
    selector: 'page-pos-manajemen',
    templateUrl: 'pos-manajemen.html',
})
export class PosManajemen {
    dataFilter = {
        dari: "",
        sampai: ""
    }
    dataKas = {
        nama: "",
        catatan: "",
        tanggal: "",
        jumlah: "",
        type: ""
    };
    resposeData: any;
    detailKas: any;
    logins: any[];
    items: any[] = [];

    constructor(public modalCtrl: ModalController, public navCtrl: NavController,
        public navParams: NavParams,
        public alertCtrl: AlertController,
        public authService: AuthService,
        public common: Common,
        private toastCtrl: ToastController) {
        var v = new Date();
        this.dataFilter.dari = this.formatDate(v);
        this.dataFilter.sampai = this.formatDate(v);
        this.getKas();
    }

    openCalendar() {
        const options: CalendarModalOptions = {
            canBackwardsSelected: true,
            pickMode: 'range',
            title: 'Pilih Tanggal',
            defaultDate: new Date()
        };

        let myCalendar = this.modalCtrl.create(CalendarModal, {
            options: options
        });

        myCalendar.present();

        myCalendar.onDidDismiss((date: {from: CalendarResult; to: CalendarResult}, type: string) => {
            if (date === null) {
                this.dataFilter.dari = this.dataFilter.dari;
                this.dataFilter.sampai = this.dataFilter.sampai;
            } else {
                this.dataFilter.dari = date.from.string;
                this.dataFilter.sampai = date.to.string;
            }
        });
    }

    presentToast(msg) {
        let toast = this.toastCtrl.create({
            message: msg,
            duration: 3000
        });
        toast.present();
    }

    formatDate(date) {
        var d = new Date(date),
            month = '' + (d.getMonth() + 1),
            day = '' + d.getDate(),
            year = d.getFullYear();

        if (month.length < 2) month = '0' + month;
        if (day.length < 2) day = '0' + day;

        return [year, month, day].join('-');
    }

    openManagementKas() {
        this.navCtrl.push(ManagementKasFormPage);
    }

    getKas() {
        this.dataKas.type = "4";
        this.authService.postData(this.dataKas, "getManagementKas").then(
            result => {
                this.resposeData = result;
                if (this.resposeData.kasData) {
                    this.detailKas = this.resposeData.kasData;
                    for (let i = 0; i < this.resposeData.kasData.length; i++) {
                        let nama = this.resposeData.kasData[i].pemberi;
                        let penerima = this.resposeData.kasData[i].penerima;
                        let catatan = this.resposeData.kasData[i].catatan;
                        let tanggal = this.resposeData.kasData[i].tanggal;
                        let jumlah = this.resposeData.kasData[i].total_kas;
                        if(this.resposeData.kasData[i].type_kas == 'KT'){
                            var type_trans = "Cash In";
                        }else if(this.resposeData.kasData[i].type_kas == 'KK'){
                            type_trans = "Cash Out";
                        }
                        
                        this.items.push({
                            "nama": nama,
                            "penerima": penerima,
                            "catatan": catatan,
                            "tanggal": tanggal,
                            "jumlah": jumlah,
                            "type": type_trans
                        });

                    }
                } else {
                    
                }
            },
            err => {
                this.presentToast("Gagal terhubung ke server.");
            }
        );
    }
    filterData() {
        this.items=[""];
        this.authService.postData(this.dataFilter, "filterTransaksiKas").then(
            result => {
                this.resposeData = result;
                if (this.resposeData.filterData) {
                    this.detailKas = this.resposeData.filterData;
                    for (let i = 0; i < this.resposeData.filterData.length; i++) {
                        let nama = this.resposeData.filterData[i].pemberi;
                        let penerima = this.resposeData.filterData[i].penerima;
                        let catatan = this.resposeData.filterData[i].catatan;
                        let tanggal = this.resposeData.filterData[i].tanggal;
                        let jumlah = this.resposeData.filterData[i].total_kas;
                        let type_trans = "Pemindahan Kas";

                        this.items.push({
                            "nama": nama,
                            "penerima": penerima,
                            "catatan": catatan,
                            "tanggal": tanggal,
                            "jumlah": jumlah,
                            "type": type_trans
                        });

                    }
                } else {
//                    this.items.push({
//                        "nama": '',
//                        "catatan": '',
//                        "tanggal": '',
//                        "jumlah": 0,
//                        "type": ''
//                    });
                }
            },
            err => {
                this.presentToast("Gagal terhubung ke server.");
            }
        );
    }

    setItems() {
        this.items;
    }
}
